﻿/* --------------------------------------------------------------------------
   FormelnErsterLayer.mu

   Skript für MUPAD, Sonderbehandlung des ersten Layers.

   Erstellt: 2012-10-17
   Geändert: 2012-11-14, S. Reiser

   MUPAD-Programm mit abgeleiteten Formeln für den Sonderfall "Punkt im
   ersten Layer" (d.h., z >= 0 und topZ = 0) und zur Verifikation der
   gefundenen Formeln. Die hier angegebenen Formeln dienen als Referenz für
   den LEA2-Quellcode für Ausgabepunkte im ersten Layer.
   --------------------------------------------------------------------------


   Abschnitte des Skripts:

   (1) Darstellung der Koeffizientenfunktionen C(m) und D(m) als Funktionen
   von A(m) und B(m). (Im Folgenden kurz A, B, C, D.)

   Die Formeln wurden ermittelt, indem die ersten beiden Zeilen des
   Matrixgleichungssystems (aus dem LEA2-Quellcode zur Bestückung der Matrix)
   genommen und symbolisch nach C und D aufgelöst wurden. Das entspricht der
   Vorgehensweise von CAUWELAERT, Abschnitt 23.5, S. 236 (ähnlich auch in
   BISAR), nur dass die Matrix in unserer Implementierung anders bestückt
   wird: Zwar ist das Endergebnis äquivalent, aber einzelne Komponenten liegen
   auf anderen Positionen und sind anders skaliert. Entsprechende Unterschiede
   bestehen in den Formeln zur Berechnung der Stress- und Displacement-
   Komponenten.

   Überprüft wurden C(A,B) und D(A,B) mittels Open-Office-Calc: Für ein
   Beispiel-System wurde eine Tabelle der Koeffizienten A, B, C, D für knapp
   21000 Werte von m zwischen 0 und 1000 erstellt und mit den Formeln für
   C(A,B), D(A,B) verglichen.

   Anmerkung: Die Werte von C(A,B) stimmten auf je mindestens 13-14 Stellen
   mit denen von C überein (maxRelErr = 2.6e-14). Dagegen ergab sich für
   D(A,B) ein maximaler relativer Fehler von 1.65e-2. Die größten Fehler
   ergaben sich für relativ kleine m im Bereich um m = 1 herum.
   --> Noch einmal genauer untersuchen, woran das liegen könnte und ob es
   signifikante Auswirkungen auf die Ergebnisse hat. Vergleich durchführen
   zwischen Sonderbehandlung und rein numerischer Integration für ein
   geeignetes z im ersten Layer, z.B. z = 0.9, für das eine rein numerische
   Behandlung möglich ist.


   (2) Allgemeine Formeln für Szz, Srr, Stt, Szr, u, w aus dem LEA2-Quellcode.
   MUPAD liefert dann Formeln, bei denen C und D durch die in (1) ermittelten
   Ausdrücke ersetzt wurde.


   (3) Für f = Szz, Srr usw. wurden durch Ausmultiplizieren mittels expand(f)
   und durch anschließendes manuelles Vereinfachen (die Automatiken von MUPAD,
   MATLAB und REDUCE lieferten nicht die gewünschten Ergebnisse) die Formeln
   g = Szz_, Srr_ usw. hergeleitet. Die vereinfachten Formeln werden wie folgt
   verifiziert: Der Wert expand(g-f) muss jeweils 0 ergeben, wenn g und f
   äquivalent sind.

   Die Formeln Szz_, Srr_ usw. liegen als Summen in der folgenden Form vor:
   Zunächst stehen Summanden, die unabhängig von den Koeffizienten A und B
   sind. Für deren Integral von 0 bis unendlich können geschlossene
   analytische Ausdrücke gefunden werden (Tabellen von EASON-NOBLE-SNEDDON und
   KAUSEL-BAIG). Danach stehen Summanden, die Vielfache von A oder B sind.
   Da A und B für m->unendlich exponentiell abklingen, können diese Ausdrücke
   numerisch integriert werden.

   Zur Berechnung der analytischen Ausdrücke wurde hauptsächlich der kürzlich
   erschienene Artikel von Kausel und Baig verwendet, in dem insbesondere die
   Ergebnisse von Eason, Nobel und Sneddon in kompakter Form zusammengefasst
   sind. Auf letztere wurden in einigen Problemfälle zurückgegriffen (speziell
   für r=R, den Rand der Last), weil sich die Darstellung von Kausel und Baig
   in diesen Fällen als zur direkten Implementierung ungeeignet erwiesen hat.
   (Beispiel ... [Konvention 0*x = 0 auch für x = unendlich...])


   (4) Für die Sonderfälle z->0 (Oberfläche) und r->0 (z-Achse) ergeben sich
   weitere Probleme: Einige der analytischen Ausdrücke ergeben dann unbestimmt
   divergente unendliche Integrale. Auch dort, wo die analytischen Ausdrücke
   aus der Literatur zumindest rein formal einen endlichen Wert liefern -- so
   findet sich z.B. bei CAUWELAERT der Wert 1/b^2 für das unendliche Integral
   INT[J1(b*t)*t*dt], Gl. 8.7, obwohl hier der Integrand für große t beliebig
   wächst --, darf dieser nicht einfach als Grenzwert eines divergenten
   Integrals eingesetzt werden. (Das scheint vergleichbar mit den möglichen
   Schwierigkeiten, die sich bei rein formalen Operationen, etwa dem Umordnen,
   mit divergenten unendlichen Reihen ergeben können -- hier lassen sich mit
   etwas Glück zwar richtige, aber oft auch beliebige falsche Ergebnisse
   herleiten.)

   Für die Behandlung der Oberfläche wurden die ermittelten Funktionen Szz_,
   Srr_ usw. daher noch einmal unter den Zusatzbedingungen z=0, A=0, B=0
   ausgewertet, woraus sich die Funktionen Szz_z0, Srr_z0 usw. ergeben, bei
   denen nur der analytische Anteil für Punkte an der Oberfläche übrigbleibt.
   (Der numerisch zu integrierende Anteil der Funktionen Szz_ usw. macht für
   z=0 dagegen keine Probleme.) Es zeigt sich, dass sich die problematischen
   Ausdrücke dadurch in allen Fällen bereits im Integranden auflösen, so dass
   "unmögliche" Integrale nicht länger auftreten.


   (5) Für beliebige z>=0 ergibt sich bei Punkten auf der z-Achse, d.h. mit
   r=0, bei einigen Komponenten eine Division durch 0. In diesen Komponenten
   kommt außerdem der Term J1(m*r/R) vor, wodurch hier Fälle von "0/0"
   vorliegen, die sich durch die de l'Hospitalschen Regeln für den Grenzwert
   r->0 aufgelösen lassen. (Implementierung: Für einen geeignet zu wählenden
   Schwellwert R_THRESHOLD setzt man für r<R_THRESHOLD den Grenzwert ein und
   rechnet für r>=R_THRESHOLD mit der herkömmlichen Formel.)


   Anmerkungen:

   -  Die Koeffizienten A, B, C, D werden im Skript als AA, BB, CC und DD
      geschrieben, weil in MUPAD der Bezeichner "D" einen Operator darstellt.
      Zwar lässt sich die Bedeutung von "D" aufheben, aber es zeigte sich,
      dass es zumindest in der vorliegenden Version 2.5 trotzdem Probleme beim
      Vereinfachen von Gleichungen gibt, wenn darin Variablen namens "D"
      verwendet werden.

   -  Die Bezeichner J1_m, J1_mrR und J0_mrR stehen für die Werte der
      Besselfunktionen J1 und J0 an den Stellen m und m*r/R.


   Literatur:

       Frans Van Cauwelaert.  _Pavement Design and Evaluation: The Required
           Mathematics and Its Applications_.  Edited by Marc Stet.
           Federation of the Belgian Cement Industry, 2003

       Eduardo Kausel and Mirza M. Irfan Baig.  "Laplace transform of products
           of Bessel functions: A visitation of earlier formulas."
           Quart. Appl. Math. 70 (2012): 77--97.

       G. Eason, B. Noble and I. N. Sneddon.  "On Certain Integrals of
           Lipschitz-Hankel Type Involving Products of Bessel Functions".
           Philosophical Transactions of the Royal Society of London.
           Series A 247 (1955): 529--551

*/

PRETTYPRINT := FALSE;

assume(Type::Real);  // Alle Bezeichner sind reelle Zahlen.
assume(m   >= 0);    // Integrationsvariable m nicht-negativ.
assume(R   >  0);    // Radius der Last positiv.
assume(h   >  0);    // Dicke des Layers positiv.
assume(z   >= 0);    // Koordinate z des Ausgabepunkts nicht-negativ.
assume(r   >= 0);    // Koordinate r des Ausgabepunkts nicht-negativ.
assume(ela >  0);    // E-Modul positiv.

topZ := 0;           // Oberkante des Layers = 0 <==> erster Layer.

// --------------------------------------------------------------------------
// (1) C und D als Funktionen von A und B.
// --------------------------------------------------------------------------
CC := AA*(4*nu-1)/exp(1/R*h*m)+4*BB*R/m*nu*(-1+2*nu)/exp(1/R*h*m)+2*R/m*nu
      /exp(1/R*h/2*m);
DD := (BB*(4*nu-1)/exp(1/R*h*m)+2/R*m*AA/exp(1/R*h*m))+1/exp(1/R*h/2*m);

// --------------------------------------------------------------------------
// (2) Allgemeine Formeln für Szz, Srr usw. (aus LEA2-Quellcode).
// --------------------------------------------------------------------------
EX := exp(m*(h/2-z+topZ)/R);
MEX := exp(-m*(h/2-z+topZ)/R);

Szz := -J1_m*J0_mrR
     /R*( (R*DD+m*z*DD-2*R*nu*DD+CC*m)*EX + (BB*R-AA*m-BB*m*z-2*BB*R*nu)*MEX);

Srr := J1_m*J1_mrR
         /r * ((-CC+R*DD/m-z*DD)*EX+(AA+BB*z+BB*R/m)*MEX)
     + J1_m*J0_mrR
         *((CC*m/R-DD+m*z*DD/R-2*nu*DD)*EX+(-BB-AA*m/R-BB*m*z/R-2*BB*nu)*MEX);

Stt := J1_m*J1_mrR
         /r*((CC-R*DD/m+z*DD)*EX+(-BB*R/m-AA-BB*z)*MEX)
     + J1_m*J0_mrR
         *((-2*nu*DD )*EX+(-2*BB*nu)*MEX);

Szr := -J1_m*J1_mrR
         /R*((m*z*DD-2*R*nu*DD+CC*m)*EX+(AA*m+BB*m*z+2*BB*R*nu)*MEX);

u := J1_m*J1_mrR/m
         *(1+nu)/ela*((CC*m+m*z*DD-R*DD)*EX+(-BB*R-AA*m-BB*m*z)*MEX);

w := J1_m*J0_mrR/m*
         (1+nu)/ela*((-4*R*nu*DD+CC*m+2*R*DD+m*z*DD)*EX
        +(-2*BB*R+4*BB*R*nu+AA*m+BB*m*z)*MEX);

// --------------------------------------------------------------------------
// (3) Ermittelte Formeln Szz_, Srr_ usw., in denen C, D eliminiert wurden.
// --------------------------------------------------------------------------
Srr_:=
-1                 *J1_m*J0_mrR/exp(1/R*m*z)
+z/R               *J1_m*J0_mrR/exp(1/R*m*z) *m
-z /r              *J1_m*J1_mrR/exp(1/R*m*z)
+(R/r*(1-2*nu))    *J1_m*J1_mrR/exp(1/R*m*z) /m

+J1_m*J0_mrR/exp(1/R*h*m)^(1/2)*(
  AA*m/R*(-exp(1/R*m*z)+(-3+2/R*m*z)/exp(1/R*m*z))
 +BB*((-1-2*nu-1/R*m*z)*exp(1/R*m*z)+(1+m/R*z*(4*nu-1)-6*nu)/exp(1/R*m*z))
)
+J1_m*J1_mrR /r /exp(1/R*h/2*m)*(
  AA*(exp(1/R*m*z)+(3-4*nu-2/R*m*z)/exp(1/R*m*z))
 +BB*((z+R/m)*exp(1/R*m*z)+(R/m*(-1+8*nu*(1-nu))+z*(1-4*nu))/exp(1/R*m*z))
);


Stt_ :=
- 2*nu             *J1_m*J0_mrR/exp(1/R*m*z)
+ z/r              *J1_m*J1_mrR/exp(1/R*m*z)
+(R/r*(-1+2*nu))   *J1_m*J1_mrR/exp(1/R*m*z) /m

+(nu*(-2*BB*exp(1/R*m*z)+(-4/R*m*AA+BB*(2-8*nu))/exp(1/R*m*z))
 )*J1_m*J0_mrR/exp(1/R*h/2*m)
//!!! Hier 1/r ausklammern. Könnte in der Summe für r->0 problematisch werden...
 +(AA/r*(-exp(1/R*m*z)+(-3+4*nu+2/R*m*z)/exp(1/R*m*z))
 +BB/r*((-z-R/m)*exp(1/R*m*z)+(z*(-1+4*nu)+R/m*(1+nu*(-8+8*nu)))/exp(1/R*m*z))
)*J1_m*J1_mrR/exp(1/R*h/2*m);


Szz_ :=
- 1/R*z            *J1_m*J0_mrR/exp(1/R*m*z) *m
- 1                *J1_m*J0_mrR/exp(1/R*m*z)
+(AA/R*m*(exp(1/R*m*z)+(-1-2/R*m*z)/exp(1/R*m*z))
 +BB*((-1+2*nu+1/R*m*z)*exp(1/R*m*z)+(1-2*nu+1/R*m*z-4/R*m*z*nu)/exp(1/R*m*z))
 )*J1_m*J0_mrR/exp(1/R*h*m)^(1/2);


Szr_ :=
- z/R              *J1_m*J1_mrR/exp(1/R*m*z) *m
+(AA*m/R*(-exp(1/R*m*z)+(1-2/R*m*z)/exp(1/R*m*z))
+(BB*((-2*nu-1/R*m*z)*exp(1/R*m*z)+(2*nu+m/R*(z-4*z*nu))/exp(1/R*m*z)))
)*J1_m*J1_mrR/exp(1/R*h/2*m);


u_ :=
          z*(1+nu) /ela*J1_m*J1_mrR/exp(1/R*m*z)
+R*(-1+nu*(1+2*nu))/ela*J1_m*J1_mrR/exp(1/R*m*z) /m

+1/ela*J1_m*J1_mrR/exp(1/R*h/2*m)*(
+AA*((-1-nu)*exp(1/R*m*z)+(2/R*m*z-3+nu*(1+4*nu+2/R*m*z))/exp(1/R*m*z))
+BB*((z*(-1-nu)+R/m*(-1-nu))*exp(1/R*m*z)
    +(z*(-1+nu*(3+4*nu))+R/m*(1+nu*(-7+8*nu*nu)))/exp(1/R*m*z)));


w_:=
z*(1+nu)/ela       *J1_m*J0_mrR/exp(1/R*m*z)
+2*R*(1-nu*nu)/ela *J1_m*J0_mrR/exp(1/R*m*z) /m

+(AA*((1+nu)*exp(1/R*m*z)+(3+nu*(-1-4*nu)+2/R*m*z*(nu+1))/exp(1/R*m*z))
 +BB*((z*(1+nu)+2*R/m*(-1+nu*(1+2*nu)))*exp(1/R*m*z)
     +(z*(-1+3*nu+4*nu*nu)+2*R/m*(-1+nu*(3-4*nu*nu)))/exp(1/R*m*z))
 )/ela*J1_m*J0_mrR/exp(1/R*h/2*m);

// --------------------------------------------------------------------------
// (3.1) Verifikation
// --------------------------------------------------------------------------
veri :=        expand(Srr_-Srr);
veri := veri + expand(Stt_-Stt);
veri := veri + expand(Szz_-Szz);
veri := veri + expand(Szr_-Szr);
veri := veri + expand(u_-u);
veri := veri + expand(w_-w);
veri; // Muss 0 sein.

// --------------------------------------------------------------------------
// (4) Sonderfall Oberfläche, z = 0, analytischer Anteil (A=0, B=0)
// --------------------------------------------------------------------------
z  := 0;
AA := 0;
BA := 0:

// Ergebnisse nach Vereinfachnung:
Srr_z0 := R*J1_m*J1_mrR/m/r*(1-2*nu) - J1_m*J0_mrR;
Stt_z0 := R*J1_m*J1_mrR/m/r*(2*nu-1) - 2*nu*J1_m*J0_mrR;
Szz_z0 := -J1_m*J0_mrR;
Szr_z0 := 0;
u_z0   := R*J1_m*J1_mrR/m/ela*(-1+nu*(1+2*nu));
w_z0   := R*J1_m*J0_mrR/m/ela*2*(1-nu*nu);

// Verifikation:
veri := veri + expand(Srr_z0-Srr);
veri := veri + expand(Stt_z0-Stt);
veri := veri + expand(Szz_z0-Szz);
veri := veri + expand(Szr_z0-Szr);
veri := veri + expand(u_z0-u);
veri := veri + expand(w_z0-w);
veri; // Muss 0 sein.

// Zusätzlich für Fall r=0, also speziell im Urspung:
// J1_(m*r/R) wird 0, J0(m*r/R) wird 1.
// De l'Hospitalsche Regel: Grenzwert für r->0 von J1(m*r/R)/r ist m/2/R.
Srr_z0r0 := J1_m*((.5-nu)-1);
Stt_z0r0 := J1_m*((nu-.5)-2*nu);
Szz_z0r0 := -J1_m;
Szr_z0r0 := 0;
u_z0r0   := 0;
w_z0r0   := R*J1_m/m/ela*2*(1-nu*nu);

// Integrale des analytischen Anteils können direkt angegeben werden:
// INT(J1(x)dx) = 1.
I_Srr_z0r0 := (.5-nu)-1;
I_Stt_z0r0 := (nu-.5)-2*nu;
I_Szz_z0r0 := -1;
I_Szr_z0r0 := 0;
I_u_z0r0   := 0;
I_w_z0r0   := R/ela*2*(1-nu*nu);

